@@ -2,8 +2,11 @@ import os
 import json
 from six.moves.urllib.parse import urlparse
 
+# NOTE: The endpoints below will soon become deprecated/removed, as the default in the
+# latest version is to access all services via a single "edge service" (port 4566)
 _service_endpoints_template = {
     'dashboard': '{proto}://{host}:8080',
+    'edge': '{proto}://{host}:4566',
     'apigateway': '{proto}://{host}:4567',
     'apigatewayv2': '{proto}://{host}:4567',
     'kinesis': '{proto}://{host}:4568',
@@ -66,9 +69,16 @@ _service_endpoints_template = {
     'mediastore-data': '{proto}://{host}:4617',
     'transfer': '{proto}://{host}:4618',
     'acm': '{proto}://{host}:4619',
-    'codecommit': '{proto}://{host}:4620'
+    'codecommit': '{proto}://{host}:4620',
+    'kinesisanalytics': '{proto}://{host}:4621'
 }
 
+# TODO remove service port mapping above entirely
+if False:
+    for key, value in _service_endpoints_template.items():
+        if key != 'dashboard':
+            _service_endpoints_template[key] = '%s:4566' % value.rpartition(':')[0]
+
 
 def get_service_endpoint(service, localstack_host=None):
     endpoints = get_service_endpoints(localstack_host=localstack_host)
